==> org.eclipse.pde.core.source_3.9.1.v20130628-1111.jar: org/eclipse/pde/internal/core/target/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2013 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.internal.core.target;

import org.eclipse.osgi.util.NLS;

/**
 *
 */
public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.pde.internal.core.target.Messages"; //$NON-NLS-1$
	public static String AbstractBundleContainer_1;
	public static String AbstractBundleContainer_3;
	public static String AbstractTargetHandle_0;
	public static String DirectoryBundleContainer_0;
	public static String DirectoryBundleContainer_1;
	public static String DirectoryBundleContainer_2;
	public static String DirectoryBundleContainer_3;
	public static String FeatureBundleContainer_0;
	public static String FeatureBundleContainer_1;
	public static String FeatureBundleContainer_2;
	public static String FeatureBundleContainer_4;
	public static String IUBundleContainer_0;
	public static String IUBundleContainer_1;
	public static String IUBundleContainer_10;
	public static String IUBundleContainer_11;
	public static String IUBundleContainer_2;
	public static String IUBundleContainer_3;
	public static String IUBundleContainer_4;
	public static String IUBundleContainer_5;
	public static String IUBundleContainer_6;
	public static String IUBundleContainer_7;
	public static String IUBundleContainer_8;
	public static String IUBundleContainer_9;
	public static String IUBundleContainer_ProblemsLoadingRepositories;
	public static String LoadTargetDefinitionJob_0;
	public static String LoadTargetDefinitionJob_1;
	public static String LoadTargetOperation_argsTaskName;
	public static String LoadTargetOperation_envTaskName;
	public static String LoadTargetOperation_implicitPluginsTaskName;
	public static String LoadTargetOperation_jreTaskName;
	public static String LoadTargetOperation_loadPluginsTaskName;
	public static String LoadTargetOperation_mainTaskName;
	public static String LoadTargetOperation_reloadTaskName;
	public static String LocalTargetHandle_0;
	public static String LocalTargetHandle_1;
	public static String LocalTargetHandle_2;
	public static String LocalTargetHandle_3;
	public static String LocalTargetHandle_4;
	public static String LocalTargetHandle_5;
	public static String P2TargetUtils_ProvisioningSourceTask;
	public static String ProfileBundleContainer_0;
	public static String ProfileBundleContainer_1;
	public static String ProfileBundleContainer_2;
	public static String TargetDefinition_0;
	public static String TargetDefinition_1;
	public static String TargetDefinition_2;
	public static String TargetDefinition_3;
	public static String TargetDefinition_4;
	public static String TargetDefinition_5;
	public static String TargetDefinition_RequiredFeatureCouldNotBeFound;
	public static String TargetDefinitionPersistenceHelper_0;
	public static String TargetDefinitionPersistenceHelper_1;
	public static String TargetDefinitionPersistenceHelper_2;
	public static String TargetDefinitionPersistenceHelper_WrongRootElementInXML;
	public static String TargetFeature_FileDoesNotExist;
	public static String TargetPersistence38Helper_NoTargetLocationExtension;
	public static String TargetPlatformService_0;
	public static String TargetPlatformService_1;
	public static String TargetPlatformService_2;
	public static String TargetPlatformService_3;
	public static String TargetPlatformService_4;
	public static String TargetPlatformService_5;
	public static String TargetPlatformService_7;
	public static String WorkspaceFileTargetHandle_0;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> org.eclipse.pde.core.source_3.12.0.v20180516-1159.jar: org/eclipse/pde/internal/core/target/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2016 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.internal.core.target;

import org.eclipse.osgi.util.NLS;

/**
 *
 */
public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.pde.internal.core.target.Messages"; //$NON-NLS-1$
	public static String AbstractBundleContainer_1;
	public static String AbstractBundleContainer_3;
	public static String AbstractTargetHandle_0;
	public static String DirectoryBundleContainer_0;
	public static String DirectoryBundleContainer_1;
	public static String FeatureBundleContainer_0;
	public static String FeatureBundleContainer_1;
	public static String FeatureBundleContainer_2;
	public static String FeatureBundleContainer_4;
	public static String IUBundleContainer_0;
	public static String IUBundleContainer_1;
	public static String IUBundleContainer_10;
	public static String IUBundleContainer_11;
	public static String IUBundleContainer_2;
	public static String IUBundleContainer_3;
	public static String IUBundleContainer_4;
	public static String IUBundleContainer_5;
	public static String IUBundleContainer_6;
	public static String IUBundleContainer_7;
	public static String IUBundleContainer_8;
	public static String IUBundleContainer_9;
	public static String IUBundleContainer_ProblemsLoadingRepositories;
	public static String LoadTargetDefinitionJob_0;
	public static String LoadTargetOperation_jreTaskName;
	public static String LoadTargetOperation_mainTaskName;
	public static String LocalTargetHandle_0;
	public static String LocalTargetHandle_1;
	public static String LocalTargetHandle_2;
	public static String LocalTargetHandle_3;
	public static String LocalTargetHandle_4;
	public static String LocalTargetHandle_5;
	public static String P2TargetUtils_ProvisioningSourceTask;
	public static String ProfileBundleContainer_0;
	public static String ProfileBundleContainer_1;
	public static String ProfileBundleContainer_2;
	public static String TargetBundle_ErrorReadingManifest;
	public static String TargetDefinition_0;
	public static String TargetDefinition_1;
	public static String TargetDefinition_2;
	public static String TargetDefinition_3;
	public static String TargetDefinition_4;
	public static String TargetDefinition_5;
	public static String TargetDefinition_RequiredFeatureCouldNotBeFound;
	public static String TargetDefinitionPersistenceHelper_0;
	public static String TargetDefinitionPersistenceHelper_1;
	public static String TargetDefinitionPersistenceHelper_2;
	public static String TargetDefinitionPersistenceHelper_WrongRootElementInXML;
	public static String TargetFeature_FileDoesNotExist;
	public static String TargetPersistence38Helper_NoTargetLocationExtension;
	public static String TargetPlatformService_0;
	public static String TargetPlatformService_1;
	public static String TargetPlatformService_2;
	public static String TargetPlatformService_3;
	public static String TargetPlatformService_4;
	public static String TargetPlatformService_5;
	public static String TargetPlatformService_6;
	public static String TargetPlatformService_7;
	public static String WorkspaceFileTargetHandle_0;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
